using System;
using System.Collections;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "The corpse of Wonder Woman" )]
	public class WonderWoman : BaseCreature
	{
		[Constructable]
		public WonderWoman() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 ) 
		{
			Name = "Wonder Woman";
			Body = 401; 
			Hue = 1009;
                        BaseSoundID = 333;


			
		    	SetStr( 1000 );
			SetDex( 500 );
			SetInt( 500);

			SetHits( 5000 );

			SetDamage( 15, 25 );

			SetDamageType( ResistanceType.Physical, 100 );
			

			SetResistance( ResistanceType.Physical, 60 );
			SetResistance( ResistanceType.Fire, 60 );
			SetResistance( ResistanceType.Cold, 60 );
			SetResistance( ResistanceType.Poison, 60 );
			SetResistance( ResistanceType.Energy, 60 );

						

			Fame = 1000;
			Karma = -1000;

			VirtualArmor = 20;

			
			Unicorn mare = new Unicorn();
        	        mare.Hue = 1153;
        	        mare.Rider = this;

			Item chest = new FemaleStuddedChest();
                        chest.Hue = 37;
                        AddItem( chest );
			AddItem( new ThighBoots( 4 ) );
                        AddItem( new Cloak( 1153 ) );
			AddItem( new LongHair( 1 ) );

			Bow bow = new Frostbringer();

			bow.Movable = false;
			bow.Crafter = this;
			bow.Quality = WeaponQuality.Exceptional;

			AddItem( bow );

			Container pack = new Backpack();

			pack.Movable = false;

			Arrow arrows = new Arrow( 350 );

			arrows.LootType = LootType.Newbied;

			pack.DropItem( arrows );
			pack.DropItem( new Gold( 3500, 5000 ) );

			AddItem( pack );

			Skills[SkillName.Anatomy].Base = 120.0;
			Skills[SkillName.Tactics].Base = 120.0;
			Skills[SkillName.Archery].Base = 120.0;
			Skills[SkillName.MagicResist].Base = 120.0;
			Skills[SkillName.DetectHidden].Base = 100.0;

			
		}

                public override bool AlwaysMurderer{ get{ return true; } }

		public override bool OnBeforeDeath()
		{
			IMount mount = this.Mount;

			if ( mount != null )
				mount.Rider = null;

			if ( mount is Mobile )
				((Mobile)mount).Delete();

			return base.OnBeforeDeath();
		}

                    public void DrainLife()
		{
			Map map = this.Map;

			if ( map == null )
				return;

			IPooledEnumerable eable = map.GetMobilesInRange( this.Location, 2 );
			ArrayList list = new ArrayList();

			foreach ( Mobile m in eable )
			{
				if ( m == this || !CanBeHarmful( m ) )
					continue;

				if ( m is BaseCreature && (((BaseCreature)m).Controled || ((BaseCreature)m).Summoned || ((BaseCreature)m).Team != this.Team) )
					list.Add( m );
				else if ( m.Player )
					list.Add( m );
			}

			eable.Free();

			foreach ( Mobile m in list )
			{
				DoHarmful( m );

				m.FixedParticles( 0x374A, 10, 15, 5013, 0x496, 0, EffectLayer.Waist );
				m.PlaySound( 0x29 );
				m.PlaySound( 0x207); 
				m.SendMessage( "Your feel a shock and your life drains!" );

				int toDrain = Utility.RandomMinMax( 10, 40 );

				Hits += toDrain;
				m.Damage( toDrain, this );
			}
		}

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			base.OnGaveMeleeAttack( defender );

			if ( 0.1 >= Utility.RandomDouble() )
				DrainLife();
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			base.OnGotMeleeAttack( attacker );

			if ( 0.1 >= Utility.RandomDouble() )
				DrainLife();
		}

		  
      		     


		public WonderWoman( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
